Quantcast
Channel: OpenCL*
Browsing index pages (491 articles)

Image may be NSFW.
Clik here to view.

RFE: Intel native one workitem per hardware thread kernel that supports...

Here's a pie-in-the-sky request for enhancement... :)It would be useful if we could create OpenCL/SPIR-* kernels that mapped one workitem to a single EU hardware thread and exposed the thread's entire...

View Article


Image may be NSFW.
Clik here to view.

Can not process a big image!

I happen to the problem that processing a 7360px*4912px image with the intel OpenCL SDK leads to "GPU stop response!" , but using the same code in the AMD GPU and NVIDIA GPU can process successfuly....

View Article


Image Read Failure in OpenCL

I am trying to use OpenCL to create a 3D texture and read in the kernel (clCreateImage). The texture read always returns 0 on Intel GPU device, but it works ok on CPU device. I wrote a simple test...

View Article

Is branch divergence as much of a concern with Intel Graphics as it is with...

I'm new to GPU development and targeting the heavily SIMD-nature of GPUs. I have read a fair amount about branch divergence, and how excessive conditional branching in logic executed on GPUs can cause...

View Article

Looking for detailed specs and architecture details for 5th and 6th gen Intel...

Hello,I am building an opencl application to target 5th and 6th generation intel GPUs.Where is the best place to find up to date information on architecture and how to optimizefor these...

View Article


CPU Only OpenCL driver - no release since 2014 ?

Hello,I notice that the latest driver for CPU only is dated May 2014. Have there been no updates sincethat date?  No bug fixes ?   Please advise. Thanks!Aaron 

View Article

clEnqueueUnmapMemObject CL_OUT_OF_HOST_MEMORY

I'm trying to run my program on an Intel HD Graphics 4600 device with driver version 20.19.15.4331.The source code to the program is here:https://github.com/david3x3x3/eternity2I'm running the program...

View Article

Image may be NSFW.
Clik here to view.

Video Streaming Processing - Going Green

IntroductionAnnual global IP traffic will surpass the zettabyte threshold this year and double that yearly rate by 20191. Having already increased more than fivefold just in the past 5 years, traffic...

View Article


Seeing different performance numbers than sample code

I'm experimenting with the sample applications found here: https://software.intel.com/en-us/articles/optimizing-simple-opencl-kernels. And in particular I'm looking at the simple modulate example. I'm...

View Article


cl_khr_fp16 support on Gen8 or 9?

I don't see the cl_khr_fp16 extension in the latest Broadwell OpenCL driver under Win10.Does it exist in a Skylake Gen9 IGP OpenCL driver under Win10?I see that it has been added to the Beignet Linux...

View Article

Cannot get "Jump Start Tutorial" to build

Totally green with openCL. I'm trying to get the source from this tutorial to build. But I cannot. In particular, I'm getting CL_INVALID_MEM_OBJECT when executing the following code:  err =...

View Article

Image may be NSFW.
Clik here to view.

Resultados do Intel IoT Roadshow de Novembro de 2015

 Durante os dias 6 e 7 de Novembro de 2015, realizamos a terceira edição do Intel IoT Roadshow em São Paulo, no Insper. Contamos com a presença de 117 desenvolvedores, que com a ajuda de 15 mentores...

View Article

OpenCL Code builder doesn't work anymore after upate

I've updated OpenCL SDK and now nothing works anymore. Previously analyzed and working kernels just hang in OpenCL Code builder. With VS2013 plugin I just get Messages that the Connection to the Server...

View Article


Installing both Intel CPU and GPU drivers

hi forumI first installed the OpenCL 1.2 Driver (intel-opencl-1.2-devel-1.0-47971.x86_64) for Intel HD graphics on my Ubuntu box (involving patching and installing Linux kernel 4.1), downloaded from...

View Article

auto-vectorization question

can someone comment on my question posted in the below link? especially regarding my Question#1?https://forums.khronos.org/showthread.php/13009-Vectorization-on-various...thanks

View Article


Intel SDK 2016

Hi all,I'd like to extent my programming skills in OpenCl Programming. Right now I modelling environmental questions in Java, but I'd like to improve computation speed with using OpenCl.So I downloaded...

View Article

question on autovectorization

Does  autovectorization work on below kernel? __kernel void vec_add(__global const float* in1, __global const float* in2, __global float* out) {    int i=get_global_id(0);    int j=(i<<2);...

View Article


optimize kernel for vector addition

I have 2 vectors (float) with size of 1024*1024*8.  I want to do vector addition. My first kernel vec_add_1() has Gx=1024*1024*8 and Lx=0__kernel void vec_add_1(__global const float* in1, __global...

View Article

high cpu usage on module libigdrcl

Hi,After running some performance tests on VtuneAMP and VisiualStudio performance Analyzer, they both showed that the module libigdrcl took a lot of CPU usage.Is this module  the  opencl driver...

View Article

Where can I find OpenCL driver for Cherry Trail devices?

Many BayTrail Android devices are shipped with OpenCL driver by default, but it's no longer the case for CherryTrail. So is OpenCL still supported by modern Android IA devices?It seems that Intel® SDK...

View Article
Browsing index pages (491 articles)


Latest Images